==> ejc-purchasingmanagement-impl-3.0.0-20220718.141214-167-sources.jar: com/ejianc/business/purchasingmanagement/controller/FreighttransferController.java <==
package com.ejianc.business.purchasingmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.*;
import com.ejianc.business.purchasingmanagement.service.IFreighttransferdetailService;
import com.ejianc.business.purchasingmanagement.service.ITransportationacceptanceService;
import com.ejianc.business.purchasingmanagement.vo.SalesreconciliationVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.purchasingmanagement.service.IFreighttransferService;
import com.ejianc.business.purchasingmanagement.vo.FreighttransferVO;

/**
 * 采购运费调账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("freighttransfer")
public class FreighttransferController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IFreighttransferService service;
    @Autowired
    private ITransportationacceptanceService transportationacceptanceService;
    @Autowired
    private IFreighttransferdetailService freighttransferdetailService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FreighttransferVO> saveOrUpdate(@RequestBody FreighttransferVO saveOrUpdateVO) {
    	FreighttransferEntity entity = BeanMapper.map(saveOrUpdateVO, FreighttransferEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
            for(FreighttransferdetailEntity detailEntity : entity.getFreighttransferdetailList()){
                detailEntity.setId(null);
            }
        }else{
            if(saveOrUpdateVO.getFreighttransferdetailList().size() != 0 && saveOrUpdateVO.getBillState() == 0){
                QueryWrapper<FreighttransferdetailEntity> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("mid",saveOrUpdateVO.getId());
                List<FreighttransferdetailEntity> list = freighttransferdetailService.list(queryWrapper);
                //取差集
                List<FreighttransferdetailEntity> resultList = list.stream()
                        .filter(item -> !saveOrUpdateVO.getFreighttransferdetailList().stream().map(e -> e.getId()).collect(Collectors.toList()).contains(item.getId()))
                        .collect(Collectors.toList());
                for (FreighttransferdetailEntity salesreconciliationdetailEntity : resultList){
                    salesreconciliationdetailEntity.setRowState("del");
                    entity.getFreighttransferdetailList().add(salesreconciliationdetailEntity);
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	FreighttransferVO vo = BeanMapper.map(entity, FreighttransferVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FreighttransferVO> queryDetail(Long id) {
    	FreighttransferEntity entity = service.selectById(id);
    	FreighttransferVO vo = BeanMapper.map(entity, FreighttransferVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FreighttransferVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FreighttransferVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FreighttransferVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FreighttransferVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<FreighttransferEntity> page = service.queryPage(param,false);
        IPage<FreighttransferVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), FreighttransferVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FreighttransferEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Freighttransfer-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFreighttransferData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FreighttransferVO>> refFreighttransferData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<FreighttransferEntity> page = service.queryPage(param,false);
        IPage<FreighttransferVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FreighttransferVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/getMoney", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FreighttransferVO> getMoney(@RequestParam String transporterId, String contractId) {

        QueryWrapper<TransportationacceptanceEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("sum(meet_money) as total");
        //queryWrapper.eq("is_Sign",0);
        queryWrapper.eq("shippers_id",transporterId);
        queryWrapper.eq("purchasecontract_id",contractId);
        Map<String, Object> map = transportationacceptanceService.getMap(queryWrapper);
        Double total;
        if(map == null){
            total = 0.00;
        }else{
            total = Double.valueOf(String.valueOf(map.get("total")));
        }
        QueryWrapper<TransportationacceptanceEntity> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.select("sum(amount_paid) as amountpaid");
        queryWrapper1.eq("shippers_id",transporterId);
        queryWrapper1.eq("purchasecontract_id",contractId);
        Map<String, Object> map1 = transportationacceptanceService.getMap(queryWrapper1);
        Double amountpaid;
        if(map1 == null){
            amountpaid = 0.00;
        }else{
            amountpaid = Double.valueOf(String.valueOf(map1.get("amountpaid")));
        }
        FreighttransferVO freighttransferVO = new FreighttransferVO();
        freighttransferVO.setTotalAmount(BigDecimal.valueOf(total));
        freighttransferVO.setUncollectedAmount(BigDecimal.valueOf(total-amountpaid));

        return CommonResponse.success("查询金额成功！",freighttransferVO);
    }
}

==> ejc-purchasingmanagement-impl-3.0.0-20220903.162409-208-sources.jar: com/ejianc/business/purchasingmanagement/controller/FreighttransferController.java <==
package com.ejianc.business.purchasingmanagement.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.purchasingmanagement.bean.*;
import com.ejianc.business.purchasingmanagement.service.IFreighttransferdetailService;
import com.ejianc.business.purchasingmanagement.service.ITransportationacceptanceService;
import com.ejianc.business.purchasingmanagement.vo.SalesreconciliationVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.purchasingmanagement.service.IFreighttransferService;
import com.ejianc.business.purchasingmanagement.vo.FreighttransferVO;

/**
 * 采购运费调账
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("freighttransfer")
public class FreighttransferController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IFreighttransferService service;
    @Autowired
    private ITransportationacceptanceService transportationacceptanceService;
    @Autowired
    private IFreighttransferdetailService freighttransferdetailService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<FreighttransferVO> saveOrUpdate(@RequestBody FreighttransferVO saveOrUpdateVO) {
    	FreighttransferEntity entity = BeanMapper.map(saveOrUpdateVO, FreighttransferEntity.class);
        if(entity.getAdjustmentAmount().signum() == -1 ){
            if(entity.getFreighttransferdetailList().size() == 0){
                throw new BusinessException("调减时必须分配验收单信息!");
            }else{
                if(!entity.getAdjustmentBalance().equals(new BigDecimal(0.00))){
                    throw new BusinessException("调账金额未分配完不允许保存,请重新分配!");
                }
            }
        }
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
            for(FreighttransferdetailEntity detailEntity : entity.getFreighttransferdetailList()){
                detailEntity.setId(null);
            }
        }else{
            if(saveOrUpdateVO.getFreighttransferdetailList().size() != 0 && saveOrUpdateVO.getBillState() == 0){
                QueryWrapper<FreighttransferdetailEntity> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("mid",saveOrUpdateVO.getId());
                List<FreighttransferdetailEntity> list = freighttransferdetailService.list(queryWrapper);
                //取差集
                List<FreighttransferdetailEntity> resultList = list.stream()
                        .filter(item -> !saveOrUpdateVO.getFreighttransferdetailList().stream().map(e -> e.getId()).collect(Collectors.toList()).contains(item.getId()))
                        .collect(Collectors.toList());
                for (FreighttransferdetailEntity salesreconciliationdetailEntity : resultList){
                    salesreconciliationdetailEntity.setRowState("del");
                    entity.getFreighttransferdetailList().add(salesreconciliationdetailEntity);
                }
            }
        }
    	service.saveOrUpdate(entity, false);
    	FreighttransferVO vo = BeanMapper.map(entity, FreighttransferVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FreighttransferVO> queryDetail(Long id) {
    	FreighttransferEntity entity = service.selectById(id);
    	FreighttransferVO vo = BeanMapper.map(entity, FreighttransferVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<FreighttransferVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (FreighttransferVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(FreighttransferVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<FreighttransferVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("transporterName");
        fuzzyFields.add("contractName");
        fuzzyFields.add("materialName");
        fuzzyFields.add("billCode");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache =sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if(StringUtils.isNotBlank(authOrgIds)){//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        }else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });
        if(CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if(CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("projectDepartmentId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<FreighttransferEntity> page = service.queryPage(param,false);
        IPage<FreighttransferVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), FreighttransferVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<FreighttransferEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Freighttransfer-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refFreighttransferData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<FreighttransferVO>> refFreighttransferData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<FreighttransferEntity> page = service.queryPage(param,false);
        IPage<FreighttransferVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), FreighttransferVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/getMoney", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<FreighttransferVO> getMoney(@RequestParam String transporterId, String contractId) {

        QueryWrapper<TransportationacceptanceEntity> queryWrapper = new QueryWrapper<>();
        queryWrapper.select("sum(meet_money) as total");
        //queryWrapper.eq("is_Sign",0);
        queryWrapper.eq("shippers_id",transporterId);
        queryWrapper.eq("purchasecontract_id",contractId);
        Map<String, Object> map = transportationacceptanceService.getMap(queryWrapper);
        Double total;
        if(map == null){
            total = 0.00;
        }else{
            total = Double.valueOf(String.valueOf(map.get("total")));
        }
        QueryWrapper<TransportationacceptanceEntity> queryWrapper1 = new QueryWrapper<>();
        queryWrapper1.select("sum(amount_paid) as amountpaid");
        queryWrapper1.eq("shippers_id",transporterId);
        queryWrapper1.eq("purchasecontract_id",contractId);
        Map<String, Object> map1 = transportationacceptanceService.getMap(queryWrapper1);
        Double amountpaid;
        if(map1 == null){
            amountpaid = 0.00;
        }else{
            amountpaid = Double.valueOf(String.valueOf(map1.get("amountpaid")));
        }
        FreighttransferVO freighttransferVO = new FreighttransferVO();
        freighttransferVO.setTotalAmount(BigDecimal.valueOf(total));
        freighttransferVO.setUncollectedAmount(BigDecimal.valueOf(total-amountpaid));

        return CommonResponse.success("查询金额成功！",freighttransferVO);
    }
}
